#' @keywords internal
"_PACKAGE"

# Declare global variables to avoid R CMD check notes
utils::globalVariables("id")

## usethis namespace: start
#' @importFrom sf st_sf
#' @import dplyr
#' @importFrom methods is as
#' @importFrom stats end na.omit
#' @importFrom rlang .data
# @importFrom raster rasterToPoints as.data.frame clump rasterize cellFromXY merge as.matrix ncell plot
# @importFrom sp SpatialPoints Line Lines SpatialLines CRS
#' @importFrom data.table data.table := .N setDT setnames
#' @importClassesFrom terra SpatRaster
#' @importMethodsFrom terra plot
## usethis namespace: end
NULL
